@@ -8,6 +8,7 @@ import websocket
 import requests
 from threading import Thread
 import datetime
+import logging
 
 from typing import Optional
 from requests.exceptions import HTTPError, RequestException, Timeout
@@ -26,6 +27,7 @@ from .const import (
 )
 from .errors import FireServiceRotaError, InvalidAuthError, ExpiredTokenError, InvalidTokenError
 
+_LOGGER = logging.getLogger("pyfireservicerota")
 
 class FireServiceRota(object):
     """Class for communicating with the fireservicerota API."""
@@ -96,10 +98,10 @@ class FireServiceRota(object):
         if not self._user:
             self._get_userid()
 
-        today = datetime.date.today()
+        today = datetime.datetime.now().astimezone()
         tomorrow = today + datetime.timedelta(days = 1)
         id =  self._user['memberships'][0]['id']
-        url = FSR_ENDPOINT_MEMBERSHIPS.format(id, today, tomorrow)
+        url = FSR_ENDPOINT_MEMBERSHIPS.format(id, today.strftime("%Y-%m-%dT00:00:00%z"), tomorrow.strftime("%Y-%m-%dT00:00:00%z"))
 
         response = self._request('GET', endpoint=url, log_msg_action='get memberships',
                  auth_request=False)
@@ -160,40 +162,49 @@ class FireServiceRota(object):
         if not self._user:
             self._get_userid()
 
-        today = datetime.date.today()
+        today = datetime.datetime.now().astimezone()
         tomorrow = today + datetime.timedelta(days = 1)
 
         id =  self._user['memberships'][0]['id']
-        url = FSR_ENDPOINT_MEMBERSHIPS.format(id, today, tomorrow)
+        url = FSR_ENDPOINT_MEMBERSHIPS.format(id, today.strftime("%Y-%m-%dT00:00:00%z"), tomorrow.strftime("%Y-%m-%dT00:00:00%z"))
 
         response = self._request('GET', endpoint=url, log_msg_action='get memberships',
                  auth_request=False)
 
-        for interval in response['intervals']:
-          if interval['available'] == True:
-            now = datetime.datetime.now().astimezone()
-            if now > datetime.datetime.strptime(interval['start_time'], "%Y-%m-%dT%H:%M:%S.%f%z") and now < datetime.datetime.strptime(interval['end_time'], "%Y-%m-%dT%H:%M:%S.%f%z"):
-               if 'standby_duty' in interval['detailed_availability']:
-                   interval['type'] = 'standby_duty'
-               elif 'exception' in interval['detailed_availability']:
-                   interval['type'] = 'exception'
-               elif 'recurring' in interval['detailed_availability']:
-                   interval['type'] = 'recurring'
-               else:
-                   interval['type'] = 'unknown'
+        if response:
+            for interval in response['intervals']:
+                if interval['available'] == True:
+                    now = datetime.datetime.now().astimezone()
+                    if now > datetime.datetime.strptime(interval['start_time'], "%Y-%m-%dT%H:%M:%S.%f%z") and now < datetime.datetime.strptime(interval['end_time'], "%Y-%m-%dT%H:%M:%S.%f%z"):
+                        if 'standby_duty' in interval['detailed_availability']:
+                            interval['type'] = 'standby_duty'
+                        elif 'exception' in interval['detailed_availability']:
+                            interval['type'] = 'exception'
+                        elif 'recurring' in interval['detailed_availability']:
+                            interval['type'] = 'recurring'
+                        else:
+                            interval['type'] = 'unknown'
 
-               if interval['assigned_function_ids']:
-                   for func in interval['assigned_function_ids']:
-                       interval['assigned_function'] = self.get_standby_function(func)['name']
+                        if interval['assigned_function_ids']:
+                            for func in interval['assigned_function_ids']:
+                                interval['assigned_function'] = self.get_standby_function(func)['name']
 
-               return interval
+                        return interval
 
+        interval = {}
         interval['available'] = False
         return interval
 
 
-    def update(self):
-        return self.get_availability()
+    def update(self, id):
+
+        response = {}
+        avail = self.get_availability()
+
+        if id:
+            response = self.get_incident_response(id)
+
+        return ({**avail,**response})
 
 
     def _request(
@@ -351,7 +362,7 @@ class FireServiceRotaIncidents(Thread, websocket.WebSocketApp):
             else:
                 _LOGGER.debug(f"Received unknown type: {message}")
         except Exception as e:
-            logging.exception(e)
+            _LOGGER.exception(e)
 
 
     def run_forever(self, sockopt=None, sslopt=None, ping_interval=0, ping_timeout=None):
